@@ -1,19 +1,17 @@
 from superset.extensions import celery_app
 from celery.utils.log import get_task_logger
 from supersetpdfreport.pdf_report import PDF_report
-from typing import Any
-import logging
+from supersetpdfreport.config import PDF_REPORT_JOB_FOLDER
+from supersetpdfreport.logging import logger
 import glob
 
-logger = get_task_logger(__name__)
-logger.setLevel(logging.INFO)
-
 
 @celery_app.task(name="reports-pdf-scheduler")
 def reports_pdf_scheduler() -> None:
 
     logger.info("superset_pdf_report started")
-    joblist = glob.glob('*.json')
+    joblist = glob.glob('{}*.json'.format(PDF_REPORT_JOB_FOLDER))
+    logger.info(joblist)
 
     for job_name in joblist:
         pdf_report_task = PDF_report()
@@ -21,5 +19,3 @@ def reports_pdf_scheduler() -> None:
     
     
     logger.info("superset_pdf_report finished")
-
-reports_pdf_scheduler()
